---
name: New Generator
about: Suggest a new output format for Padrick
title: ''
labels: output format
assignees: ''

---

**New Output Format**
Please describe the new output format and its intended use case.

**Are changes or additions to Padricks configuration file format required?**
If yes, please describe them.
